#
# Copyright (c) 2015-2021 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyramid.view import view_config

from onf_website.features.alert.zmi import AlertPermissionMixin, check_alert_view
from pyams_content.features.alert.interfaces import IAlertContainer, IAlertTarget
from pyams_content.features.alert.zmi import AlertContainerView as AlertContainerViewBase
from pyams_content.features.alert.zmi.container import AlertsMenu as AlertsMenuBase, \
    set_alerts_order as set_alerts_order_base, \
    switch_alert_visibility as switch_alert_visibility_base
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.layer import IPyAMSLayer
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.interfaces.menu import ISiteManagementMenu


@viewlet_config(name='alerts.menu',
                context=IAlertTarget, layer=IPyAMSLayer,
                manager=ISiteManagementMenu, weight=30)
class AlertsMenu(AlertPermissionMixin, AlertsMenuBase):
    """Alerts menu"""


@view_config(name='set-alerts-order.json',
             context=IAlertContainer, request_type=IPyAMSLayer,
             renderer='json', xhr=True)
def set_alerts_order(request):
    check_alert_view(request)
    return set_alerts_order_base(request)


@view_config(name='switch-alert-visibility.json',
             context=IAlertContainer, request_type=IPyAMSLayer,
             renderer='json', xhr=True)
def switch_alert_visibility(request):
    check_alert_view(request)
    return switch_alert_visibility_base(request)


@pagelet_config(name='alerts.html',
                context=IAlertTarget, layer=IPyAMSLayer)
class AlertContainerView(AlertPermissionMixin, AlertContainerViewBase):
    """Alerts view"""
