#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from pyramid.events import subscriber
from zope.component.interfaces import ISite
from zope.container.contained import Contained
from zope.interface import implementer
from zope.lifecycleevent.interfaces import IObjectAddedEvent
from zope.schema.fieldproperty import FieldProperty

from onf_website.reference.forest.interfaces import IForestTable
from pyams_i18n.interfaces import II18nManager
from pyams_utils.traversing import get_parent


@implementer(IForestTable, II18nManager)
class ForestTable(Persistent, Contained):
    """Forest table manager"""

    title = FieldProperty(IForestTable['title'])
    short_name = FieldProperty(IForestTable['short_name'])

    languages = FieldProperty(II18nManager['languages'])

    forest_displays = FieldProperty(IForestTable['forest_displays'])


@subscriber(IObjectAddedEvent, context_selector=IForestTable)
def handle_added_target_table(event):
    """Handle new target table"""
    site = get_parent(event.object, ISite)
    registry = site.getSiteManager()
    if registry is not None:
        registry.registerUtility(event.object, IForestTable)
